﻿using SimplePermission.Domain;
using System;
using System.Linq;
using System.Security.Permissions;
using System.Web.Security;

namespace SimplePermission.Services
{
    public class AccountService : IAccountService
    {
        private IUserRepo _repo;

        public AccountService(IUserRepo repo)
        {
            _repo = repo;
        }

        public void SignIn(string userName, bool createPersistentCookie)
        {
            FormsAuthentication.SetAuthCookie(userName, createPersistentCookie);
        }

        [PrincipalPermission(SecurityAction.Demand)]
        public void SignOut()
        {
            FormsAuthentication.SignOut();
        }

        public string[] GetRolesForUser(string username)
        {
            var role = _repo.FindByUserName(username).Role;
            if (role == Role.None)
            {
                return new string[] { };
            }
            return Enum.GetValues(typeof(Role)).Cast<Role>()
                .Where(o => (role & o) == o)
                .Select(o => Enum.GetName(typeof(Role), o))
                .ToArray();
        }

        public bool IsUserInRole(string username, string roleName)
        {
            var role = (Role)Enum.Parse(typeof(Role), roleName);
            return _repo.FindByUserName(username).Role.HasFlag(role);
        }
    }
}